@@ -18,7 +18,7 @@ from warnings import warn
 import numpy as np
 
 import theano
-from theano import change_flags, config, gof
+from theano import config, gof
 from theano.compile.function.types import (
     Function,
     FunctionMaker,
@@ -27,8 +27,9 @@ from theano.compile.function.types import (
 )
 from theano.compile.mode import Mode, register_mode
 from theano.compile.ops import OutputGuard, _output_guard
-from theano.gof import graph, link, ops_with_inner_function, utils
-from theano.gof.link import raise_with_op
+from theano.gof import graph, ops_with_inner_function, utils
+from theano.link.basic import Container, LocalLinker
+from theano.link.utils import map_storage, raise_with_op
 from theano.utils import get_unbound_function
 
 
@@ -1739,18 +1740,17 @@ class _DummyLinker:
         return self
 
 
-class _Linker(gof.link.LocalLinker):
+class _Linker(LocalLinker):
     """
     Special debugging linker.
 
     """
 
     def __init__(self, maker, schedule=None):
-        super(gof.LocalLinker, self).__init__()
+        super().__init__()
         self.fgraph = None
         self.maker = maker
-        if schedule:
-            self.schedule = schedule
+        super().__init__(scheduler=schedule)
 
     def accept(self, fgraph, no_recycling=None, profile=None):
         if no_recycling is None:
@@ -1793,7 +1793,7 @@ class _Linker(gof.link.LocalLinker):
         # the function's outputs will always be freshly allocated.
         no_recycling = []
 
-        input_storage, output_storage, storage_map = link.map_storage(
+        input_storage, output_storage, storage_map = map_storage(
             fgraph, order, input_storage_, output_storage_, storage_map
         )
 
@@ -2341,11 +2341,11 @@ class _Linker(gof.link.LocalLinker):
         return (
             f,
             [
-                link.Container(input, storage, readonly=False)
+                Container(input, storage, readonly=False)
                 for input, storage in zip(fgraph.inputs, input_storage)
             ],
             [
-                link.Container(output, storage, readonly=True)
+                Container(output, storage, readonly=True)
                 for output, storage in zip(fgraph.outputs, output_storage)
             ],
             thunks_py,
@@ -2446,7 +2446,7 @@ class _Maker(FunctionMaker):  # inheritance buys a few helper functions
             )
             fgraph.equivalence_tracker = equivalence_tracker
 
-            with change_flags(compute_test_value=config.compute_test_value_opt):
+            with config.change_flags(compute_test_value=config.compute_test_value_opt):
                 optimizer(fgraph)
 
                 theano.compile.function.types.insert_deepcopy(
@@ -2506,7 +2506,7 @@ class _Maker(FunctionMaker):  # inheritance buys a few helper functions
                             file=sys.stderr,
                         )
         self.fgraph = fgraph
-        if theano.config.cycle_detection == "regular":
+        if config.cycle_detection == "regular":
             destroy_handler_added = False
             for feature in fgraph._features:
                 if isinstance(feature, gof.DestroyHandler):
@@ -2516,7 +2516,9 @@ class _Maker(FunctionMaker):  # inheritance buys a few helper functions
                 fgraph.attach_feature(gof.DestroyHandler())
             for o in fgraph.outputs:
                 try:
-                    with change_flags(compute_test_value=config.compute_test_value_opt):
+                    with config.change_flags(
+                        compute_test_value=config.compute_test_value_opt
+                    ):
                         fgraph.replace_validate(
                             o, _output_guard(o), reason="output_guard"
                         )
@@ -2564,7 +2566,7 @@ class _Maker(FunctionMaker):  # inheritance buys a few helper functions
         self.refeed = [
             (
                 i.value is not None
-                and not isinstance(i.value, gof.Container)
+                and not isinstance(i.value, Container)
                 and i.update is None
             )
             for i in self.inputs
