@@ -21,6 +21,8 @@ from theano.compile.ops import deep_copy_op, view_op
 from theano.gof import graph
 from theano.gof.op import ops_with_inner_function
 from theano.gof.toolbox import is_same_graph
+from theano.link.basic import Container
+from theano.link.utils import raise_with_op
 
 
 _logger = logging.getLogger("theano.compile.function.types")
@@ -440,7 +442,7 @@ class Function:
 
                 if value is not None:
                     # Always initialize the storage.
-                    if isinstance(value, gof.Container):
+                    if isinstance(value, Container):
                         # There is no point in obtaining the current value
                         # stored in the container, since the container is
                         # shared.
@@ -485,7 +487,7 @@ class Function:
                         "names of the inputs of your function "
                         "for duplicates."
                     )
-                if isinstance(s, gof.Container):
+                if isinstance(s, Container):
                     return s.value
                 else:
                     raise NotImplementedError
@@ -503,7 +505,7 @@ class Function:
                         "names of the inputs of your function "
                         "for duplicates."
                     )
-                if isinstance(s, gof.Container):
+                if isinstance(s, Container):
                     s.value = value
                     s.provided += 1
                 else:
@@ -812,7 +814,7 @@ class Function:
         def restore_defaults():
             for i, (required, refeed, value) in enumerate(self.defaults):
                 if refeed:
-                    if isinstance(value, gof.Container):
+                    if isinstance(value, Container):
                         value = value.storage[0]
                     self[i] = value
 
@@ -978,7 +980,7 @@ class Function:
                 thunk = None
                 if hasattr(self.fn, "thunks"):
                     thunk = self.fn.thunks[self.fn.position_of_error]
-                gof.link.raise_with_op(
+                raise_with_op(
                     self.maker.fgraph,
                     node=self.fn.nodes[self.fn.position_of_error],
                     thunk=thunk,
@@ -1153,7 +1155,7 @@ def _pickle_Function(f):
 
 
 def _constructor_Function(maker, input_storage, inputs_data, trust_input=False):
-    if not theano.config.unpickle_function:
+    if not config.unpickle_function:
         return None
 
     f = maker.create(input_storage, trustme=True)
@@ -1360,7 +1362,7 @@ class FunctionMaker:
 
         from theano.gof.compilelock import get_lock, release_lock
 
-        graph_db_file = os.path.join(theano.config.compiledir, "optimized_graphs.pkl")
+        graph_db_file = os.path.join(config.compiledir, "optimized_graphs.pkl")
 
         # the inputs, outputs, and size of the graph to be optimized
         inputs_new = [inp.variable for inp in inputs]
@@ -1379,12 +1381,12 @@ class FunctionMaker:
                     print(f"create new graph_db in {graph_db_file}")
             # load the graph_db dictionary
             try:
-                with open(graph_db_file, "rb") as f:
+                with open(graph_db_file, "rb") as f, config.change_flags(
+                    unpickle_function=False
+                ):
                     # Temporary hack to allow
                     # tests.scan.test_scan.T_Scan to
                     # finish. Should be changed in definitive version.
-                    tmp = theano.config.unpickle_function
-                    theano.config.unpickle_function = False
                     graph_db = pickle.load(f)
                 print("graph_db loaded and it is not empty")
             except EOFError as e:
@@ -1392,8 +1394,6 @@ class FunctionMaker:
                 print(e)
                 print("graph_db loaded and it is empty")
                 graph_db = {}
-            finally:
-                theano.config.unpickle_function = tmp
 
             return graph_db
 
@@ -1536,7 +1536,7 @@ class FunctionMaker:
             #    too much execution time during testing as we compile
             #    much more functions then the number of compile c
             #    module.
-            theano.gof.cc.get_module_cache().refresh()
+            theano.link.c.basic.get_module_cache().refresh()
         # Handle the case where inputs and/or outputs is a single
         # Variable (not in a list)
         unpack_single = False
@@ -1583,50 +1583,52 @@ class FunctionMaker:
         # Fetch the optimizer and linker
         optimizer, linker = mode.optimizer, copy.copy(mode.linker)
         if need_opt:
-            compute_test_value_orig = theano.config.compute_test_value
-            limit_orig = theano.config.traceback__limit
             # Why we add stack on node when it get done in output var?
             try:
-                # optimize the fgraph
-                theano.config.compute_test_value = theano.config.compute_test_value_opt
-                theano.config.traceback__limit = theano.config.traceback__compile_limit
                 start_optimizer = time.time()
 
                 # In case there is an error during optimization.
                 optimizer_profile = None
                 opt_time = None
 
-                # now optimize the graph
-                if theano.config.cache_optimizations:
-                    optimizer_profile = self.optimize_graph_with_cache(
-                        optimizer, inputs, outputs
-                    )
-                else:
-                    optimizer_profile = optimizer(fgraph)
+                with config.change_flags(
+                    compute_test_value=config.compute_test_value_opt,
+                    traceback__limit=config.traceback__compile_limit,
+                ):
+                    # now optimize the graph
+                    if config.cache_optimizations:
+                        optimizer_profile = self.optimize_graph_with_cache(
+                            optimizer, inputs, outputs
+                        )
+                    else:
+                        optimizer_profile = optimizer(fgraph)
 
-                end_optimizer = time.time()
-                opt_time = end_optimizer - start_optimizer
-                _logger.debug(f"Optimizing took {opt_time:f} seconds")
+                    end_optimizer = time.time()
+                    opt_time = end_optimizer - start_optimizer
+                    _logger.debug(f"Optimizing took {opt_time:f} seconds")
 
-                # Add deep copy to respect the memory interface
-                insert_deepcopy(fgraph, inputs, outputs + additional_outputs)
+                    # Add deep copy to respect the memory interface
+                    insert_deepcopy(fgraph, inputs, outputs + additional_outputs)
             finally:
-                theano.config.compute_test_value = compute_test_value_orig
-                theano.config.traceback__limit = limit_orig
 
                 # If the optimizer got interrupted
                 if opt_time is None:
                     end_optimizer = time.time()
                     opt_time = end_optimizer - start_optimizer
+
                 theano.compile.profiling.total_graph_opt_time += opt_time
+
                 if profile:
                     if optimizer_profile is None and hasattr(optimizer, "pre_profile"):
                         optimizer_profile = optimizer.pre_profile
+
                     profile.optimizer_time += opt_time
-                    if theano.config.profile_optimizer:
+
+                    if config.profile_optimizer:
                         profile.optimizer_profile = (optimizer, optimizer_profile)
-                # IF False, if mean the profile for that function was explicitly disabled
-                elif theano.config.profile_optimizer and profile is not False:
+                # IF False, if mean the profile for that function was
+                # explicitly disabled
+                elif config.profile_optimizer and profile is not False:
                     warnings.warn(
                         (
                             "config.profile_optimizer requires config.profile to "
@@ -1679,7 +1681,7 @@ class FunctionMaker:
         self.refeed = [
             (
                 i.value is not None
-                and not isinstance(i.value, gof.Container)
+                and not isinstance(i.value, Container)
                 and i.update is None
             )
             for i in self.inputs
@@ -1687,7 +1689,7 @@ class FunctionMaker:
 
     def _check_unused_inputs(self, inputs, outputs, on_unused_input):
         if on_unused_input is None:
-            on_unused_input = theano.config.on_unused_input
+            on_unused_input = config.on_unused_input
 
         if on_unused_input == "ignore":
             return
@@ -1772,8 +1774,8 @@ class FunctionMaker:
             if isinstance(input_storage_i, gof.Variable):
                 input_storage_i = input_storage_i.container
 
-            if isinstance(input_storage_i, gof.Container):
-                # If the default is a gof.Container, this means we want to
+            if isinstance(input_storage_i, Container):
+                # If the default is a Container, this means we want to
                 # share the same storage. This is done by appending
                 # input_storage_i.storage to input_storage_lists.
                 if indices is not None:
@@ -1815,15 +1817,12 @@ class FunctionMaker:
 
         # Get a function instance
         start_linker = time.time()
-        start_import_time = theano.gof.cmodule.import_time
-        limit_orig = theano.config.traceback__limit
-        try:
-            theano.config.traceback__limit = theano.config.traceback__compile_limit
+        start_import_time = theano.link.c.cmodule.import_time
+
+        with config.change_flags(traceback__limit=config.traceback__compile_limit):
             _fn, _i, _o = self.linker.make_thunk(
                 input_storage=input_storage_lists, storage_map=storage_map
             )
-        finally:
-            theano.config.traceback__limit = limit_orig
 
         end_linker = time.time()
 
@@ -1833,7 +1832,7 @@ class FunctionMaker:
         if self.profile:
             self.profile.linker_time += linker_time
             _fn.time_thunks = self.profile.flag_time_thunks
-            import_time = theano.gof.cmodule.import_time - start_import_time
+            import_time = theano.link.c.cmodule.import_time - start_import_time
             self.profile.import_time += import_time
 
         fn = self.function_builder(
@@ -1857,8 +1856,8 @@ class FunctionMaker:
 def _constructor_FunctionMaker(kwargs):
     # Needed for old pickle
     # Old pickle have at least the problem that output_keys where not saved.
-    if theano.config.unpickle_function:
-        if theano.config.reoptimize_unpickled_function:
+    if config.unpickle_function:
+        if config.reoptimize_unpickled_function:
             del kwargs["fgraph"]
         return FunctionMaker(**kwargs)
     else:
@@ -1965,7 +1964,7 @@ def orig_function(
             output_keys=output_keys,
             name=name,
         )
-        with theano.change_flags(compute_test_value="off"):
+        with config.change_flags(compute_test_value="off"):
             fn = m.create(defaults)
     finally:
         t2 = time.time()
