@@ -57,7 +57,7 @@ class ViewOp(Op):
         z[0] = x
 
     def __str__(self):
-        return "%s" % self.__class__.__name__
+        return f"{self.__class__.__name__}"
 
     def c_code(self, node, nodename, inp, out, sub):
         (iname,) = inp
@@ -81,9 +81,9 @@ class ViewOp(Op):
         ):
             if not v:
                 warnings.warn(
-                    "Type %s has C code for ViewOp, but it has no "
+                    f"Type {t} has C code for ViewOp, but it has no "
                     "version. You should add a 'version' keyword "
-                    "arg when calling register_view_op_c_code." % t,
+                    "arg when calling register_view_op_c_code.",
                     stacklevel=2,
                 )
                 return ()
@@ -91,7 +91,7 @@ class ViewOp(Op):
 
         return tuple(version)
 
-    def infer_shape(self, node, input_shapes):
+    def infer_shape(self, fgraph, node, input_shapes):
         return input_shapes
 
     def grad(self, args, g_outs):
@@ -181,10 +181,10 @@ class DeepCopyOp(Op):
         ):
             if not v:
                 warnings.warn(
-                    "Type %s has C code for DeepCopyOp, but it has "
+                    f"Type {t} has C code for DeepCopyOp, but it has "
                     "no version. You should add a 'version' keyword"
                     " arg when calling "
-                    "register_deep_copy_op_c_code." % t,
+                    "register_deep_copy_op_c_code.",
                     stacklevel=2,
                 )
                 return ()
@@ -262,7 +262,7 @@ class Shape(Op):
         (out,) = out_
         out[0] = theano._asarray(np.shape(x), dtype="int64")
 
-    def infer_shape(self, node, in_shapes):
+    def infer_shape(self, fgraph, node, in_shapes):
         return [[len(in_shapes[0])]]
 
     def connection_pattern(self, node):
@@ -306,9 +306,9 @@ class Shape(Op):
         ):
             if not v:
                 warnings.warn(
-                    "Type %s has C code for Shape, but it has no "
+                    f"Type {t} has C code for Shape, but it has no "
                     "version. You should add a 'version' keyword "
-                    "arg when calling register_shape_c_code." % t,
+                    "arg when calling register_shape_c_code.",
                     stacklevel=2,
                 )
                 return ()
@@ -393,9 +393,9 @@ class Shape_i(Op):
         ):
             if not v:
                 warnings.warn(
-                    "Type %s has C code for Shape_i, but it has "
+                    f"Type {t} has C code for Shape_i, but it has "
                     "no version. You should add a 'version' keyword "
-                    "arg when calling register_shape_i_c_code." % t,
+                    "arg when calling register_shape_i_c_code.",
                     stacklevel=2,
                 )
                 return ()
@@ -421,7 +421,7 @@ class Shape_i(Op):
         # Else, no C code
         return super().c_code(node, name, inames, onames, sub)
 
-    def infer_shape(self, node, input_shapes):
+    def infer_shape(self, fgraph, node, input_shapes):
         return [()]
 
     def connection_pattern(self, node):
@@ -455,17 +455,13 @@ def shape_i(var, i, fgraph=None):
 
     Parameters
     ----------
-    var
+    var : Variable
         The variable we want to take the shape of.
-    i
+    i : int
         The shape dimensions we want
-    fgraph : optional
-        If var.fgraph do not exist, the fgraph that have the shape_feature to
-        introduce var in to get the optimized shape.
+    fgraph : FunctionGraph (optional)
 
     """
-    if fgraph is None and hasattr(var, "fgraph"):
-        fgraph = var.fgraph
     if fgraph and hasattr(fgraph, "shape_feature"):
         shape_feature = fgraph.shape_feature
         shape_of = shape_feature.shape_of
@@ -579,17 +575,17 @@ class FromFunctionOp(Op):
             obj = load_back(mod, name)
         except (ImportError, KeyError, AttributeError):
             raise pickle.PicklingError(
-                "Can't pickle as_op(), not found as {}.{}".format(mod, name)
+                f"Can't pickle as_op(), not found as {mod}.{name}"
             )
         else:
             if obj is not self:
                 raise pickle.PicklingError(
-                    "Can't pickle as_op(), not the object " "at %s.%s" % (mod, name)
+                    f"Can't pickle as_op(), not the object at {mod}.{name}"
                 )
         return load_back, (mod, name)
 
-    def _infer_shape(self, node, input_shapes):
-        return self.__infer_shape(node, input_shapes)
+    def _infer_shape(self, fgraph, node, input_shapes):
+        return self.__infer_shape(fgraph, node, input_shapes)
 
 
 def as_op(itypes, otypes, infer_shape=None):
@@ -600,7 +596,7 @@ def as_op(itypes, otypes, infer_shape=None):
     It takes an optional infer_shape parameter that should be a callable with
     this signature:
 
-        def infer_shape(node, input_shapes):
+        def infer_shape(fgraph, node, input_shapes):
             ...
             return output_shapes
 
@@ -696,14 +692,11 @@ class Rebroadcast(Op):
         self.axis = OrderedDict(items)
         for axis, broad in self.axis.items():
             if not isinstance(axis, (np.integer, int)):
-                raise TypeError(
-                    "Rebroadcast needs integer axes. " "Got {}".format(axis)
-                )
+                raise TypeError(f"Rebroadcast needs integer axes. Got {axis}")
 
             if not isinstance(broad, (np.bool_, bool)):
                 raise TypeError(
-                    "Rebroadcast needs bool for new broadcast "
-                    "pattern. Got {}".format(broad)
+                    f"Rebroadcast needs bool for new broadcast pattern. Got {broad}"
                 )
 
     def __hash__(self):
@@ -719,7 +712,7 @@ class Rebroadcast(Op):
             broadcast_pattern = ["?" for i in range(1 + max(self.axis.keys()))]
         for k, v in self.axis.items():
             broadcast_pattern[k] = str(int(v))
-        return "{}{{{}}}".format(self.__class__.__name__, ",".join(broadcast_pattern))
+        return f"{self.__class__.__name__}{{{','.join(broadcast_pattern)}}}"
 
     def make_node(self, x):
         if self.axis.keys() and (x.ndim <= max(self.axis.keys())):
@@ -737,8 +730,8 @@ class Rebroadcast(Op):
         for axis, value in self.axis.items():
             if value and x.shape[axis] != 1:
                 raise ValueError(
-                    "Dimension %s in Rebroadcast's input was"
-                    " supposed to be 1 (got %s instead)" % (axis, x.shape[axis])
+                    f"Dimension {axis} in Rebroadcast's input was"
+                    f" supposed to be 1 (got {x.shape[axis]} instead)"
                 )
         out[0] = x
 
@@ -755,7 +748,7 @@ class Rebroadcast(Op):
             )(gz),
         )
 
-    def infer_shape(self, node, ishapes):
+    def infer_shape(self, fgraph, node, ishapes):
         assert len(ishapes) == 1
         l = []
         one = theano.tensor.basic.constant(1)
@@ -786,12 +779,11 @@ class Rebroadcast(Op):
                     final_code += code % locals()
             return (
                 final_code
-                + """
-            Py_XDECREF(%(oname)s);
-            %(oname)s = %(iname)s;
-            Py_XINCREF(%(oname)s);
+                + f"""
+            Py_XDECREF({oname});
+            {oname} = {iname};
+            Py_XINCREF({oname});
             """
-                % locals()
             )
         return super().c_code(node, nodename, inp, out, sub)
 
@@ -804,10 +796,10 @@ class Rebroadcast(Op):
         ):
             if not v:
                 warnings.warn(
-                    "Type %s has C code for Rebroadcast, but it "
+                    f"Type {t} has C code for Rebroadcast, but it "
                     "has no version. You should add a 'version' "
                     "keyword arg when calling "
-                    "register_rebroadcast_c_code." % t,
+                    "register_rebroadcast_c_code.",
                     stacklevel=2,
                 )
                 return ()
@@ -884,7 +876,7 @@ class SpecifyShape(Op):
         assert np.all(x.shape == shape), ("got shape", x.shape, "expected", shape)
         out[0] = x
 
-    def infer_shape(self, node, shapes):
+    def infer_shape(self, fgraph, node, shapes):
         xshape, sshape = shapes
         new_shape = []
         for dim in range(node.inputs[0].ndim):
