@@ -1,18 +1,9 @@
 """Graph optimization framework"""
 
 import theano
-from theano.gof.cc import CLinker, DualLinker, HideC, OpWiseCLinker
 from theano.gof.destroyhandler import DestroyHandler
 from theano.gof.fg import FunctionGraph, InconsistencyError, MissingInputError
 from theano.gof.graph import Apply, Constant, Variable, view_roots
-from theano.gof.link import (
-    Container,
-    Linker,
-    LocalLinker,
-    PerformLinker,
-    WrapLinker,
-    WrapLinkerMany,
-)
 from theano.gof.op import (
     COp,
     Op,
@@ -54,9 +45,3 @@ from theano.gof.toolbox import (
 )
 from theano.gof.type import CEnumType, EnumList, EnumType, Generic, Type, generic
 from theano.gof.utils import MethodNotDefined, hashtype, object2
-
-
-if theano.config.cmodule__preload_cache:
-    from theano.gof.cc import get_module_cache
-
-    get_module_cache()
