@@ -31,7 +31,7 @@ def execute(execute=True, verbose=True, M=2000, N=2000, K=2000, iters=10, order=
 
     if verbose:
         print("Some Theano flags:")
-        print("    blas.ldflags=", theano.config.blas.ldflags)
+        print("    blas__ldflags=", theano.config.blas__ldflags)
         print("    compiledir=", theano.config.compiledir)
         print("    floatX=", theano.config.floatX)
         print("    device=", theano.config.device)
@@ -44,7 +44,7 @@ def execute(execute=True, verbose=True, M=2000, N=2000, K=2000, iters=10, order=
         print("    OMP_NUM_THREADS=", os.getenv("OMP_NUM_THREADS"))
         print("    GOTO_NUM_THREADS=", os.getenv("GOTO_NUM_THREADS"))
         print()
-        print("Numpy config: (used when the Theano flag" ' "blas.ldflags" is empty)')
+        print("Numpy config: (used when the Theano flag" ' "blas__ldflags" is empty)')
         np.show_config()
         print("Numpy dot module:", np.dot.__module__)
         print("Numpy location:", np.__file__)
@@ -290,10 +290,10 @@ if __name__ == "__main__":
         print()
         print("We executed", options.iter, end=" ")
         print("calls to gemm with a and b matrices of shapes", end=" ")
-        print("(%d, %d) and (%d, %d)." % (M, N, N, K))
+        print(f"({int(M)}, {int(N)}) and ({int(N)}, {int(K)}).")
 
         print()
-        print("Total execution time: {:.2f}s on {}.".format(t, impl))
+        print(f"Total execution time: {t:.2f}s on {impl}.")
         print()
         print(
             "Try to run this script a few times. Experience shows that"
