@@ -147,10 +147,10 @@ from theano.compile.mode import optdb
 from theano.gof import (
     Apply,
     EquilibriumOptimizer,
+    GlobalOptimizer,
     InconsistencyError,
     Op,
-    Optimizer,
-    ReplacementDidntRemovedError,
+    ReplacementDidNotRemoveError,
     SequenceDB,
     local_optimizer,
     view_roots,
@@ -189,16 +189,15 @@ try:
 except ImportError as e:
     have_fblas = False
     # This is used in Gemv and ScipyGer. We use CGemv and CGer
-    # when theano.config.blas.ldflags is defined. So we don't need a
+    # when theano.config.blas__ldflags is defined. So we don't need a
     # warning in that case.
-    if not config.blas.ldflags:
+    if not config.blas__ldflags:
         _logger.warning(
             "Failed to import scipy.linalg.blas, and "
-            "Theano flag blas.ldflags is empty. "
+            "Theano flag blas__ldflags is empty. "
             "Falling back on slower implementations for "
             "dot(matrix, vector), dot(vector, matrix) and "
-            "dot(vector, vector) (%s)",
-            str(e),
+            f"dot(vector, vector) ({str(e)})"
         )
 
 
@@ -276,8 +275,7 @@ class Gemv(Op):
             if A.shape[0] != y.shape[0] or A.shape[1] != x.shape[0]:
                 raise ValueError(
                     "Incompatible shapes for gemv "
-                    "(beta * y + alpha * dot(A, x)). y: %s, A: %s, x: %s "
-                    % (y.shape, A.shape, x.shape)
+                    f"(beta * y + alpha * dot(A, x)). y: {y.shape}, A: {A.shape}, x: {x.shape}"
                 )
 
             if beta == 0 and check_init_y():
@@ -305,7 +303,7 @@ class Gemv(Op):
                     out += y
             out_storage[0][0] = np.asarray(out, dtype=y.dtype)
 
-    def infer_shape(self, node, input_shapes):
+    def infer_shape(self, fgraph, node, input_shapes):
         return [input_shapes[0]]
 
 
@@ -374,7 +372,7 @@ class Ger(Op):
             A += np.outer(cx, cy)
         cZ[0] = A
 
-    def infer_shape(self, node, input_shapes):
+    def infer_shape(self, fgraph, node, input_shapes):
         return [input_shapes[0]]
 
 
@@ -383,7 +381,7 @@ ger_destructive = Ger(destructive=True)
 
 
 def ldflags(libs=True, flags=False, libs_dir=False, include_dir=False):
-    """Extract a list of compilation flags from config.blas.ldflags.
+    """Extract a list of compilation flags from config.blas__ldflags.
 
     Depending on the options, different type of flags will be kept.
     It returns a list of libraries against which an Op's object file
@@ -406,7 +404,7 @@ def ldflags(libs=True, flags=False, libs_dir=False, include_dir=False):
         Extracted flags.
 
     """
-    ldflags_str = theano.config.blas.ldflags
+    ldflags_str = theano.config.blas__ldflags
     return _ldflags(
         ldflags_str=ldflags_str,
         libs=libs,
@@ -426,7 +424,7 @@ def _ldflags(ldflags_str, libs, flags, libs_dir, include_dir):
     ----------
     ldflags_str : string
         The string to process. Typically, this will be the content of
-        `theano.config.blas.ldflags`.
+        `theano.config.blas__ldflags`.
     libs : bool
         Extract flags starting with "-l".
     flags: bool
@@ -476,9 +474,7 @@ def _ldflags(ldflags_str, libs, flags, libs_dir, include_dir):
             t0, t1, t2 = t[0:3]
             assert t0 == "-"
         except Exception:
-            raise ValueError(
-                'invalid token "{}" in ldflags_str: "{}"'.format(t, ldflags_str)
-            )
+            raise ValueError(f'invalid token "{t}" in ldflags_str: "{ldflags_str}"')
         if libs_dir and t1 == "L":
             rval.append(t[2:])
         elif include_dir and t1 == "I":
@@ -880,7 +876,7 @@ class Gemm(GemmRelated):
             inplace_str = "inplace"
         else:
             inplace_str = "no_inplace"
-        return "{}{{{}}}".format(self.__class__.__name__, inplace_str)
+        return f"{self.__class__.__name__}{{{inplace_str}}}"
 
     def __setstate__(self, dct):
         self.__dict__.update(dct)
@@ -901,8 +897,7 @@ class Gemm(GemmRelated):
         inputs = list(map(tt.as_tensor_variable, inputs))
         if len(inputs) != 5:
             raise TypeError(
-                "Wrong number of inputs for %s (expected 5, got %s)"
-                % (self, len(inputs))
+                f"Wrong number of inputs for {self} (expected 5, got {len(inputs)})"
             )
         z, a, x, y, b = inputs
 
@@ -974,7 +969,7 @@ class Gemm(GemmRelated):
                 z += a * np.dot(x, y)
             zout[0] = z
 
-    def infer_shape(self, node, input_shapes):
+    def infer_shape(self, fgraph, node, input_shapes):
         return [input_shapes[0]]
 
     setup_z_Nz_Sz_inplace = """
@@ -1083,7 +1078,7 @@ class Gemm(GemmRelated):
         _z, _a, _x, _y, _b = inp
         (_zout,) = out
         if node.inputs[0].type.dtype.startswith("complex"):
-            raise MethodNotDefined("%s.c_code" % self.__class__.__name__)
+            raise MethodNotDefined(f"{self.__class__.__name__}.c_code")
         full_code = self.build_gemm_call() % dict(locals(), **sub)
         return full_code
 
@@ -1103,13 +1098,13 @@ pprint.assign(gemm_inplace, FunctionPrinter("gemm_inplace"))
 pprint.assign(gemm_no_inplace, FunctionPrinter("gemm_no_inplace"))
 
 
-def res_is_a(node, op, maxclients=None):
-    if maxclients is not None:
-        retval = len(node.clients) <= maxclients
+def res_is_a(fgraph, var, op, maxclients=None):
+    if maxclients is not None and var in fgraph.clients:
+        retval = len(fgraph.get_clients(var)) <= maxclients
     else:
         retval = True
 
-    return node.owner and node.owner.op == op and retval
+    return var.owner and var.owner.op == op and retval
 
 
 def _as_scalar(res, dtype=None):
@@ -1155,7 +1150,7 @@ def _is_real_vector(res):
     )
 
 
-def _beta_L_plus_alpha_M(beta, L, alpha, M, recurse_flip=True):
+def _beta_L_plus_alpha_M(fgraph, beta, L, alpha, M, recurse_flip=True):
     # print 'BETA L + ALPHA M', beta, L, alpha, M, recurse_flip
     # EXPRESSION: (beta * L) + (alpha * M)
 
@@ -1195,45 +1190,13 @@ def _beta_L_plus_alpha_M(beta, L, alpha, M, recurse_flip=True):
             rval = [g.dimshuffle()]
             return rval, MM
 
-    # this is False'd out because of inadequate testing.
-    # TODO see ticket #237
-    if False and res_is_a(M, gemm_no_inplace, 1):
-        # EXPRESSION: (beta * L) + (alpha * (gemm_no_inplace(G, a, u, v, b)))
-        # EXPRESSION: (beta * L) + alpha * (b * G) + alpha * a * dot(u, v)
-        G, a, u, v, b = M.owner.inputs
-        # print 'GEMM', G, L
-
-        if res_is_a(G, _dot22, 1):
-            # EXPRESSION: (beta * L) +
-            #            (alpha * (gemm_no_inplace(dot(x,y), a, u, v, b)))
-            x, y = G.owner.inputs
-
-            # EXPRESSION: (beta * L) + (alpha * ((b*dot(x,y) +
-            #            (a * dot(u, v)))))
-            # EXPRESSION: (beta * L) + (alpha*b*dot(x,y)) +
-            #            (alpha * a * dot(u, v))
-            rval = [
-                gemm_no_inplace(
-                    gemm_no_inplace(L, alpha * b, x, y, beta), alpha * a, u, v, 1.0
-                )
-            ]
-            return rval
-        if G is L:
-            # EXPRESSION: (beta * L) + (alpha*b*L) + (alpha * a * dot(u, v))
-            rval = [gemm_no_inplace(L, alpha * a, u, v, alpha * b + beta)]
-            return rval
-        if 1.0 != alpha:
-            # at the very least, move the alpha inside the gemm_no_inplace
-            rval = [beta * L + gemm_no_inplace(G, alpha * a, u, v, alpha * b)]
-            return rval
-
     if recurse_flip:
-        return _beta_L_plus_alpha_M(alpha, M, beta, L, recurse_flip=False)
+        return _beta_L_plus_alpha_M(fgraph, alpha, M, beta, L, recurse_flip=False)
     else:
         return False, False
 
 
-def _gemm_canonicalize(r, scale, rval, maxclients):
+def _gemm_canonicalize(fgraph, r, scale, rval, maxclients):
     # Tries to interpret node as a sum of scalars * (vectors or matrices)
     def scaled(thing):
         if scale == 1:
@@ -1258,20 +1221,20 @@ def _gemm_canonicalize(r, scale, rval, maxclients):
         rval.append(scaled(r))
         return rval
 
-    if maxclients and len(getattr(r, "clients", [])) > maxclients:
+    if maxclients and len(fgraph.clients[r]) > maxclients:
         rval.append((scale, r))
         return rval
 
     if r.owner and r.owner.op == tt.sub:
-        _gemm_canonicalize(r.owner.inputs[0], scale, rval, 1)
-        _gemm_canonicalize(r.owner.inputs[1], -scale, rval, 1)
+        _gemm_canonicalize(fgraph, r.owner.inputs[0], scale, rval, 1)
+        _gemm_canonicalize(fgraph, r.owner.inputs[1], -scale, rval, 1)
 
     elif r.owner and r.owner.op == tt.add:
         for i in r.owner.inputs:
-            _gemm_canonicalize(i, scale, rval, 1)
+            _gemm_canonicalize(fgraph, i, scale, rval, 1)
 
     elif r.owner and r.owner.op == tt.neg:
-        _gemm_canonicalize(r.owner.inputs[0], -scale, rval, 1)
+        _gemm_canonicalize(fgraph, r.owner.inputs[0], -scale, rval, 1)
 
     elif r.owner and r.owner.op == tt.mul:
         scalars = []
@@ -1297,20 +1260,24 @@ def _gemm_canonicalize(r, scale, rval, maxclients):
             assert len(vectors) == 0
             m = matrices[0]
             if len(scalars) == 0:
-                _gemm_canonicalize(m, scale, rval, 1)
+                _gemm_canonicalize(fgraph, m, scale, rval, 1)
             elif len(scalars) == 1:
-                _gemm_canonicalize(m, scaled(scalars[0]), rval, 1)
+                _gemm_canonicalize(fgraph, m, scaled(scalars[0]), rval, 1)
             else:
-                _gemm_canonicalize(m, tt.mul(scaled(scalars[0]), *scalars[1:]), rval, 1)
+                _gemm_canonicalize(
+                    fgraph, m, tt.mul(scaled(scalars[0]), *scalars[1:]), rval, 1
+                )
         elif len(vectors) == 1:
             assert len(matrices) == 0
             v = vectors[0]
             if len(scalars) == 0:
-                _gemm_canonicalize(v, scale, rval, 1)
+                _gemm_canonicalize(fgraph, v, scale, rval, 1)
             elif len(scalars) == 1:
-                _gemm_canonicalize(v, scaled(scalars[0]), rval, 1)
+                _gemm_canonicalize(fgraph, v, scaled(scalars[0]), rval, 1)
             else:
-                _gemm_canonicalize(v, tt.mul(scaled(scalars[0]), *scalars[1:]), rval, 1)
+                _gemm_canonicalize(
+                    fgraph, v, tt.mul(scaled(scalars[0]), *scalars[1:]), rval, 1
+                )
         else:  # lets not open this up
             rval.append((scale, r))
     else:
@@ -1359,7 +1326,7 @@ def _factor_canonicalized(lst):
     return lst
 
 
-def _gemm_from_factored_list(lst):
+def _gemm_from_factored_list(fgraph, lst):
     """
     Returns None, or a list to replace node.outputs.
 
@@ -1401,7 +1368,9 @@ def _gemm_from_factored_list(lst):
 
             # print 'TRYING', (s_i, M_i, s_j, M_j)
 
-            gemm_of_sM_list, old_dot22 = _beta_L_plus_alpha_M(s_i, M_i, s_j, M_j)
+            gemm_of_sM_list, old_dot22 = _beta_L_plus_alpha_M(
+                fgraph, s_i, M_i, s_j, M_j
+            )
             # print 'GOT IT', gemm_of_sM_list
             if gemm_of_sM_list:
 
@@ -1418,7 +1387,7 @@ def _gemm_from_factored_list(lst):
                 return rval, old_dot22
 
 
-def _gemm_from_node2(node):
+def _gemm_from_node2(fgraph, node):
     """
     :todo: In many expressions, there are many ways to turn it into a
         gemm.  For example dot(a,b) + c + d.  This function should
@@ -1429,14 +1398,14 @@ def _gemm_from_node2(node):
     """
     lst = []
     t0 = time.time()
-    _gemm_canonicalize(node.outputs[0], 1.0, lst, 0)
+    _gemm_canonicalize(fgraph, node.outputs[0], 1.0, lst, 0)
     t1 = time.time()
 
     # print "GEMM CANON", lst
     if len(lst) > 1:
         lst = _factor_canonicalized(lst)
         t2 = time.time()
-        rval = _gemm_from_factored_list(lst)
+        rval = _gemm_from_factored_list(fgraph, lst)
         t3 = time.time()
 
         # It can happen that _factor_canonicalized and
@@ -1454,11 +1423,11 @@ def _gemm_from_node2(node):
     return None, t1 - t0, 0, 0
 
 
-class GemmOptimizer(Optimizer):
+class GemmOptimizer(GlobalOptimizer):
     """Graph optimizer for inserting Gemm operations."""
 
     def __init__(self):
-        Optimizer.__init__(self)
+        super().__init__()
         self.warned = False
 
     def add_requirements(self, fgraph):
@@ -1512,7 +1481,7 @@ class GemmOptimizer(Optimizer):
                     # the graph
                     continue
                 try:
-                    new_outputs, time1, time2, time3 = _gemm_from_node2(node)
+                    new_outputs, time1, time2, time3 = _gemm_from_node2(fgraph, node)
                     time_canonicalize += time1
                     time_factor_can += time2
                     time_factor_list += time3
@@ -1540,7 +1509,7 @@ class GemmOptimizer(Optimizer):
                         # TODO: retry other applications of gemm (see comment
                         # in _gemm_from_node)
                         nb_inconsistency_replace += 1
-                    except ReplacementDidntRemovedError:
+                    except ReplacementDidNotRemoveError:
                         nb_replacement_didn_t_remove += 1
                         self.warned = True
         fgraph.remove_feature(u)
@@ -1630,7 +1599,7 @@ class Dot22(GemmRelated):
             e.args = e.args + (x.shape, y.shape)
             raise
 
-    def infer_shape(self, node, input_shapes):
+    def infer_shape(self, fgraph, node, input_shapes):
         return [[input_shapes[0][0], input_shapes[1][1]]]
 
     setup_z_Nz_Sz = """
@@ -1669,7 +1638,7 @@ class Dot22(GemmRelated):
         _x, _y = inp
         (_zout,) = out
         if node.inputs[0].type.dtype.startswith("complex"):
-            raise MethodNotDefined("%s.c_code" % self.__class__.__name__)
+            raise MethodNotDefined(f"{self.__class__.__name__}.c_code")
         if len(self.c_libraries()) <= 0:
             return super().c_code(node, name, (_x, _y), (_zout,), sub)
         full_code = self.build_gemm_call() % dict(locals(), **sub)
@@ -1687,7 +1656,7 @@ _dot22 = Dot22()
 
 
 @local_optimizer([tt.Dot])
-def local_dot_to_dot22(node):
+def local_dot_to_dot22(fgraph, node):
     # This works for tensor.outer too because basic.outer is a macro that
     # produces a dot(dimshuffle,dimshuffle) of form 4 below
     if not isinstance(node.op, tt.Dot):
@@ -1696,7 +1665,7 @@ def local_dot_to_dot22(node):
     x, y = node.inputs
     if y.type.dtype != x.type.dtype:
         # TODO: upcast one so the types match
-        _logger.info("Not optimizing dot with inputs %s %s %s %s", x, y, x.type, y.type)
+        _logger.info(f"Not optimizing dot with inputs {x} {y} {x.type} {y.type}")
         return
 
     if y.type.dtype in ["float16", "float32", "float64", "complex64", "complex128"]:
@@ -1710,32 +1679,32 @@ def local_dot_to_dot22(node):
             if x.ndim == 1 and y.ndim == 1:
                 return [_dot22(x.dimshuffle("x", 0), y.dimshuffle(0, "x")).dimshuffle()]
 
-    _logger.info("Not optimizing dot with inputs %s %s %s %s", x, y, x.type, y.type)
+    _logger.info(f"Not optimizing dot with inputs {x} {y} {x.type} {y.type}")
 
 
 @local_optimizer([gemm_no_inplace], inplace=True)
-def local_inplace_gemm(node):
+def local_inplace_gemm(fgraph, node):
     if node.op == gemm_no_inplace:
         with inherit_stack_trace(node.outputs):
             return [gemm_inplace(*node.inputs)]
 
 
 @local_optimizer([gemv_no_inplace], inplace=True)
-def local_inplace_gemv(node):
+def local_inplace_gemv(fgraph, node):
     if node.op == gemv_no_inplace:
         with inherit_stack_trace(node.outputs):
             return [gemv_inplace(*node.inputs)]
 
 
 @local_optimizer([ger], inplace=True)
-def local_inplace_ger(node):
+def local_inplace_ger(fgraph, node):
     if node.op == ger:
         with inherit_stack_trace(node.outputs):
             return [ger_destructive(*node.inputs)]
 
 
 @local_optimizer([gemm_no_inplace])
-def local_gemm_to_gemv(node):
+def local_gemm_to_gemv(fgraph, node):
     """GEMM acting on row or column matrices -> GEMV."""
     if node.op == gemm_no_inplace:
         z, a, x, y, b = node.inputs
@@ -1749,7 +1718,7 @@ def local_gemm_to_gemv(node):
 
 
 @local_optimizer([gemm_no_inplace])
-def local_gemm_to_ger(node):
+def local_gemm_to_ger(fgraph, node):
     """GEMM computing an outer-product -> GER."""
     if node.op == gemm_no_inplace:
         z, a, x, y, b = node.inputs
@@ -1780,7 +1749,7 @@ def local_gemm_to_ger(node):
 # TODO: delete this optimization when we have the proper dot->gemm->ger pipeline
 #      working
 @local_optimizer([_dot22])
-def local_dot22_to_ger_or_gemv(node):
+def local_dot22_to_ger_or_gemv(fgraph, node):
     """dot22 computing an outer-product -> GER."""
     if node.op == _dot22:
         with inherit_stack_trace(node.outputs):
@@ -1905,7 +1874,7 @@ class Dot22Scalar(GemmRelated):
             e.args = e.args + (x.shape, y.shape)
             raise
 
-    def infer_shape(self, node, input_shapes):
+    def infer_shape(self, fgraph, node, input_shapes):
         return [[input_shapes[0][0], input_shapes[1][1]]]
 
     setup_z_Nz_Sz = Dot22.setup_z_Nz_Sz
@@ -1939,7 +1908,7 @@ class Dot22Scalar(GemmRelated):
         _x, _y, _a = inp
         (_zout,) = out
         if node.inputs[0].type.dtype.startswith("complex"):
-            raise MethodNotDefined("%s.c_code" % self.__class__.__name__)
+            raise MethodNotDefined(f"{self.__class__.__name__}.c_code")
         if len(self.c_libraries()) <= 0:
             return super().c_code(node, name, (_x, _y), (_zout,), sub)
         full_code = self.build_gemm_call() % dict(locals(), **sub)
@@ -1957,7 +1926,7 @@ _dot22scalar = Dot22Scalar()
 
 
 @local_optimizer([tt.mul])
-def local_dot22_to_dot22scalar(node):
+def local_dot22_to_dot22scalar(fgraph, node):
     """
     Notes
     -----
@@ -2022,11 +1991,9 @@ def local_dot22_to_dot22scalar(node):
 
         if scalar_idx < 0:
             _logger.info(
-                "Not optimizing dot22 with inputs %s %s, as the"
+                f"Not optimizing dot22 with inputs {node.inputs} {[x.type for x in node.inputs]}, as the"
                 " type of the scalar cannot be upcasted to the"
-                " matrix type",
-                node.inputs,
-                [x.type for x in node.inputs],
+                " matrix type"
             )
             return False
         a = tt.cast(_as_scalar(m.owner.inputs[scalar_idx], dtype=d.dtype), d.type.dtype)
@@ -2057,10 +2024,8 @@ def local_dot22_to_dot22scalar(node):
             break
     if scalar_idx < 0:
         _logger.info(
-            "Not optimizing dot22 with inputs %s %s, as the type "
-            "of the scalar cannot be upcasted to the matrix type",
-            node.inputs,
-            [x.type for x in node.inputs],
+            f"Not optimizing dot22 with inputs {node.inputs} {[x.type for x in node.inputs]}, as the type "
+            "of the scalar cannot be upcasted to the matrix type"
         )
         return False
     assert scalar_idx < len(node.inputs)
@@ -2099,19 +2064,19 @@ class BatchedDot(Op):
         if len(inputs) != 2:
             raise TypeError(
                 "theano.tensor.blas.BatchedDot: 2 arguments"
-                " required, %d given " % len(inputs)
+                f" required, {len(inputs)} given "
             )
         if inputs[0].ndim not in (2, 3):
             raise TypeError(
                 "theano.tensor.blas.BatchedDot: input 0 (0-indexed)"
-                " must have ndim of 2 or 3, %d given. Consider"
-                " calling theano.tensor.batched_dot instead." % inputs[0].ndim
+                f" must have ndim of 2 or 3, {int(inputs[0].ndim)} given. Consider"
+                " calling theano.tensor.batched_dot instead."
             )
         if inputs[1].ndim not in (2, 3):
             raise TypeError(
                 "theano.tensor.blas.BatchedDot: input 1 (0-indexed)"
-                " must have ndim of 2 or 3, %d given. Consider"
-                " calling theano.tensor.batched_dot instead." % inputs[1].ndim
+                f" must have ndim of 2 or 3, {int(inputs[1].ndim)} given. Consider"
+                " calling theano.tensor.batched_dot instead."
             )
 
         dtype = theano.scalar.upcast(*[input.type.dtype for input in inputs])
@@ -2130,12 +2095,11 @@ class BatchedDot(Op):
 
         if x.shape[0] != y.shape[0]:
             raise TypeError(
-                "theano.tensor.blas.BatchedDot: inputs [%s] must have the"
-                " same size in axis 0, but have sizes [%s]."
-                % (", ".join(map(str, inp)), ", ".join([str(i.shape[0]) for i in inp]))
+                f"theano.tensor.blas.BatchedDot: inputs [{', '.join(map(str, inp))}] must have the"
+                f" same size in axis 0, but have sizes [{', '.join([str(i.shape[0]) for i in inp])}]."
             )
 
-        shape = self.infer_shape(node, [i.shape for i in inp])[0]
+        shape = self.infer_shape(None, node, [i.shape for i in inp])[0]
         dtype = node.outputs[0].dtype
         z0 = z[0] = np.empty(shape, dtype=dtype)
         for i in range(z0.shape[0]):
@@ -2252,9 +2216,9 @@ class BatchedDot(Op):
 
         # generate contiguity condition
         def contiguous(var, ndim):
-            strides = "PyArray_STRIDES(%s)" % var
+            strides = f"PyArray_STRIDES({var})"
             if ndim == 1:
-                return "{strides}[0] == type_size".format(strides=strides)
+                return f"{strides}[0] == type_size"
             return " && ".join(
                 [
                     " && ".join(
@@ -2278,11 +2242,11 @@ class BatchedDot(Op):
         )
 
         # generate code to allocate output based on runtime input shapes
-        z_dims = ["PyArray_DIMS(%s)[0]" % _x]
+        z_dims = [f"PyArray_DIMS({_x})[0]"]
         if x_ndim == 3:
-            z_dims.append("PyArray_DIMS(%s)[1]" % _x)
+            z_dims.append(f"PyArray_DIMS({_x})[1]")
         if y_ndim == 3:
-            z_dims.append("PyArray_DIMS(%s)[2]" % _y)
+            z_dims.append(f"PyArray_DIMS({_y})[2]")
         assert len(z_dims) == z_ndim
 
         z_shape_correct = " && ".join(
@@ -2545,8 +2509,7 @@ class BatchedDot(Op):
                         + " and eval_point "
                         + str(i)
                         + " to BatchedDot.R_op should have the same shape, but "
-                        "their shapes are %s and %s, respectively"
-                        % (str(input_values[i].shape), str(eval_point_values[i].shape))
+                        f"their shapes are {input_values[i].shape} and {eval_point_values[i].shape}, respectively"
                     )
         if eval_points[0]:
             t1 = self(eval_points[0], inputs[1])
@@ -2560,7 +2523,7 @@ class BatchedDot(Op):
         else:
             return [t2]
 
-    def infer_shape(self, node, shapes):
+    def infer_shape(self, fgraph, node, shapes):
         for shape_ in shapes:
             if len(shape_) not in (2, 3):
                 raise NotImplementedError()
@@ -2574,6 +2537,6 @@ batched_dot = BatchedDot()
 # from opt import register_specialize, register_canonicalize
 # @register_specialize
 @local_optimizer([tt.sub, tt.add])
-def local_print_as_we_go_along(node):
+def local_print_as_we_go_along(fgraph, node):
     if node.op in (tt.sub, tt.add):
         debugprint(node)
