@@ -53,8 +53,7 @@ class Images2Neibs(Op):
         implemented_modes = self.BORDER_MODE.get_aliases()
         if mode not in implemented_modes:
             raise NotImplementedError(
-                "Only modes %s have been implemented for %s"
-                % (", ".join(implemented_modes), type(self).__name__)
+                f"Only modes {', '.join(implemented_modes)} have been implemented for {type(self).__name__}"
             )
         self.mode = mode
 
@@ -228,21 +227,20 @@ class Images2Neibs(Op):
                 raise TypeError(
                     "Images2Neibs: in wrap_centered mode, don't support"
                     " image shapes smaller then the patch shapes:"
-                    " neib_shape=(%d,%d), ten4[2:]=[%d,%d]"
-                    % (c, d, ten4.shape[2], ten4.shape[3])
+                    f" neib_shape=({int(c)},{int(d)}), ten4[2:]=[{int(ten4.shape[2])},{int(ten4.shape[3])}]"
                 )
             grid_c = CEIL_INTDIV(ten4.shape[2], step_x)
             grid_d = CEIL_INTDIV(ten4.shape[3], step_y)
         elif mode == "valid":
             if (ten4.shape[2] < c) or (((ten4.shape[2] - c) % step_x) != 0):
                 raise TypeError(
-                    "neib_shape[0]=%d, neib_step[0]=%d and"
-                    " ten4.shape[2]=%d not consistent" % (c, step_x, ten4.shape[2])
+                    f"neib_shape[0]={int(c)}, neib_step[0]={int(step_x)} and"
+                    f" ten4.shape[2]={int(ten4.shape[2])} not consistent"
                 )
             if (ten4.shape[3] < d) or (((ten4.shape[3] - d) % step_y) != 0):
                 raise TypeError(
-                    "neib_shape[1]=%d, neib_step[1]=%d and"
-                    " ten4.shape[3]=%d not consistent" % (d, step_y, ten4.shape[3])
+                    f"neib_shape[1]={int(d)}, neib_step[1]={int(step_y)} and"
+                    f" ten4.shape[3]={int(ten4.shape[3])} not consistent"
                 )
             # number of patch in height
             grid_c = 1 + ((ten4.shape[2] - c) // step_x)
@@ -261,13 +259,13 @@ class Images2Neibs(Op):
             # w + 2 * (d // 2) - c  = w - (d % 2)
             if (ten4.shape[2] < c) or (((ten4.shape[2] - (c % 2)) % step_x) != 0):
                 raise TypeError(
-                    "neib_shape[0]=%d, neib_step[0]=%d and"
-                    " ten4.shape[2]=%d not consistent" % (c, step_x, ten4.shape[2])
+                    f"neib_shape[0]={int(c)}, neib_step[0]={int(step_x)} and"
+                    f" ten4.shape[2]={int(ten4.shape[2])} not consistent"
                 )
             if (ten4.shape[3] < d) or (((ten4.shape[3] - (d % 2)) % step_y) != 0):
                 raise TypeError(
-                    "neib_shape[1]=%d, neib_step[1]=%d and"
-                    " ten4.shape[3]=%d not consistent" % (d, step_y, ten4.shape[3])
+                    f"neib_shape[0]={int(d)}, neib_step[0]={int(step_y)} and"
+                    f" ten4.shape[3]={int(ten4.shape[3])} not consistent"
                 )
             # number of patch in height
             grid_c = 1 + ((ten4.shape[2] - (c % 2)) // step_x)
@@ -281,20 +279,20 @@ class Images2Neibs(Op):
             # w + 2 * (d - 1) - c  = w + d - 2
             if (ten4.shape[2] < c) or (((ten4.shape[2] + c - 2) % step_x) != 0):
                 raise TypeError(
-                    "neib_shape[0]=%d, neib_step[0]=%d and"
-                    " ten4.shape[2]=%d not consistent" % (c, step_x, ten4.shape[2])
+                    f"neib_shape[0]={int(c)}, neib_step[0]={int(step_x)} and"
+                    f" ten4.shape[2]={int(ten4.shape[2])} not consistent"
                 )
             if (ten4.shape[3] < d) or (((ten4.shape[3] + d - 2) % step_y) != 0):
                 raise TypeError(
-                    "neib_shape[1]=%d, neib_step[1]=%d and"
-                    " ten4.shape[3]=%d not consistent" % (d, step_y, ten4.shape[3])
+                    f"neib_shape[0]={int(d)}, neib_step[0]={int(step_y)} and"
+                    f" ten4.shape[3]={int(ten4.shape[3])} not consistent"
                 )
             # number of patch in height
             grid_c = 1 + ((ten4.shape[2] + c - 2) // step_x)
             # number of patch in width
             grid_d = 1 + ((ten4.shape[3] + d - 2) // step_y)
         else:
-            raise TypeError("Images2Neibs: unknow mode '%s'" % mode)
+            raise TypeError(f"Images2Neibs: unknow mode '{mode}'")
         z_dim0 = grid_c * grid_d * ten4.shape[1] * ten4.shape[0]
         z_dim1 = c * d
         z[0] = np.empty((z_dim0, z_dim1), dtype=node.outputs[0].dtype)
@@ -346,7 +344,7 @@ class Images2Neibs(Op):
                                     else:
                                         z[0][z_row, z_col] = ten4[n, s, ten4_2, ten4_3]
 
-    def infer_shape(self, node, input_shape):
+    def infer_shape(self, fgraph, node, input_shape):
         in_shape = input_shape[0]
         c, d = node.inputs[1]
         step_x, step_y = node.inputs[2]
@@ -366,7 +364,7 @@ class Images2Neibs(Op):
             grid_c = 1 + ((in_shape[2] + c - 2) // step_x)
             grid_d = 1 + ((in_shape[3] + d - 2) // step_y)
         else:
-            raise TypeError("Images2Neibs: unknow mode '%s'" % self.mode)
+            raise TypeError(f"Images2Neibs: unknow mode '{self.mode}'")
         z_dim0 = grid_c * grid_d * in_shape[1] * in_shape[0]
         z_dim1 = c * d
         return [(z_dim0, z_dim1)]
@@ -823,6 +821,6 @@ def neibs2images(neibs, neib_shape, original_shape, mode="valid"):
         # Add a check for the good cases.
         output_4d = output_2d.reshape(original_shape, ndim=4)
     else:
-        raise NotImplementedError("neibs2images do not support mode=%s" % mode)
+        raise NotImplementedError(f"neibs2images do not support mode={mode}")
 
     return output_4d
