@@ -112,7 +112,7 @@ class SoftmaxWithBias(Op):
         db = tt.sum(dx, axis=0)
         return dx, db
 
-    def infer_shape(self, node, shape):
+    def infer_shape(self, fgraph, node, shape):
         return [shape[0]]
 
     def c_headers(self):
@@ -341,7 +341,7 @@ class SoftmaxGrad(Op):
 
         return g_dy, g_sm
 
-    def infer_shape(self, node, shape):
+    def infer_shape(self, fgraph, node, shape):
         return [shape[1]]
 
     def c_code_cache_version(self):
@@ -437,12 +437,13 @@ class Softmax(Op):
     def make_node(self, x):
         x = tt.as_tensor_variable(x)
         if x.type.ndim not in (1, 2) or x.type.dtype not in tt.float_dtypes:
-            raise ValueError("x must be 1-d or 2-d tensor of floats. Got %s" % x.type)
+            raise ValueError(f"x must be 1-d or 2-d tensor of floats. Got {x.type}")
         if x.ndim == 1:
             warnings.warn(
-                "DEPRECATION: If x is a vector, Softmax will not automatically pad x "
+                "If x is a vector, Softmax will not automatically pad x "
                 "anymore in next releases. If you need it, please do it manually. The "
                 "vector case is gonna be supported soon and the output will be a vector.",
+                category=PendingDeprecationWarning,
                 stacklevel=4,
             )
             x = tt.shape_padleft(x, n_ones=1)
@@ -467,7 +468,7 @@ class Softmax(Op):
             return [None]
         return self.L_op(inputs, [self(*inputs)], eval_points)
 
-    def infer_shape(self, node, shape):
+    def infer_shape(self, fgraph, node, shape):
         return shape
 
     def c_headers(self):
@@ -635,12 +636,13 @@ class LogSoftmax(Op):
     def make_node(self, x):
         x = tt.as_tensor_variable(x)
         if x.type.ndim not in (1, 2) or x.type.dtype not in tt.float_dtypes:
-            raise ValueError("x must be 1-d or 2-d tensor of floats. Got %s" % x.type)
+            raise ValueError(f"x must be 1-d or 2-d tensor of floats. Got {x.type}")
         if x.ndim == 1:
             warnings.warn(
-                "DEPRECATION: If x is a vector, LogSoftmax will not automatically pad x "
+                "If x is a vector, LogSoftmax will not automatically pad x "
                 "anymore in next releases. If you need it, please do it manually. The "
                 "vector case is gonna be supported soon and the output will be a vector.",
+                category=PendingDeprecationWarning,
                 stacklevel=4,
             )
             x = tt.shape_padleft(x, n_ones=1)
@@ -665,7 +667,7 @@ class LogSoftmax(Op):
             return [None]
         return self.grad(inputs, eval_points)
 
-    def infer_shape(self, node, shape):
+    def infer_shape(self, fgraph, node, shape):
         return shape
 
     def c_headers(self):
@@ -771,7 +773,7 @@ logsoftmax_op = LogSoftmax()
 # optimization to not be inserted.
 @register_specialize("stabilize", "fast_compile")
 @local_optimizer([Elemwise])
-def local_logsoftmax(node):
+def local_logsoftmax(fgraph, node):
     """
     Detect Log(Softmax(x)) and replace it with LogSoftmax(x)
 
@@ -796,7 +798,7 @@ def local_logsoftmax(node):
 # optimization to not be inserted.
 @register_specialize("stabilize", "fast_compile")
 @local_optimizer([SoftmaxGrad])
-def local_logsoftmax_grad(node):
+def local_logsoftmax_grad(fgraph, node):
     """
     Detect Log(Softmax(x))'s grad and replace it with LogSoftmax(x)'s grad
 
@@ -852,7 +854,7 @@ def logsoftmax(c):
 
 @register_specialize("fast_compile_gpu")
 @local_optimizer([softmax_op])
-def local_softmax_with_bias(node):
+def local_softmax_with_bias(fgraph, node):
     """
     Try to turn softmax(sum_of_stuff) -> softmax_w_bias(matrix, bias).
 
@@ -1068,7 +1070,7 @@ class CrossentropySoftmaxArgmax1HotWithBias(Op):
         output_storage[1][0] = sm
         output_storage[2][0] = am
 
-    def infer_shape(self, node, shapes):
+    def infer_shape(self, fgraph, node, shapes):
         x_shp, b_shp, idx_shp = shapes
         nll_shp = (x_shp[0],)
         sm_shp = x_shp
@@ -1253,7 +1255,7 @@ class CrossentropySoftmax1HotWithBiasDx(Op):
             dx[i, y_idx[i]] -= dy_i  # scalar decrement
         output_storage[0][0] = dx
 
-    def infer_shape(self, node, shapes):
+    def infer_shape(self, fgraph, node, shapes):
         return [shapes[1]]
 
     def grad(self, inp, grads):
@@ -1439,7 +1441,7 @@ class CrossentropyCategorical1HotGrad(Op):
             g_coding[i, true_one_of_n[i]] = -g_y[i] / coding_dist[i, true_one_of_n[i]]
         g_coding_strg[0] = g_coding
 
-    def infer_shape(self, node, in_shapes):
+    def infer_shape(self, fgraph, node, in_shapes):
         return [in_shapes[1]]
 
 
@@ -1484,7 +1486,7 @@ class CrossentropyCategorical1Hot(Op):
         if _true_one_of_n.type not in (tt.lvector, tt.ivector):
             raise TypeError(
                 "integer vector required for argument: true_one_of_n"
-                "(got type: %s instead of: %s)" % (_true_one_of_n.type, tt.lvector)
+                f"(got type: {_true_one_of_n.type} instead of: {tt.lvector})"
             )
 
         return Apply(
@@ -1501,7 +1503,7 @@ class CrossentropyCategorical1Hot(Op):
             y[i] = -np.log(coding[i, one_of_n[i]])
         y_out[0] = y
 
-    def infer_shape(self, node, in_shapes):
+    def infer_shape(self, fgraph, node, in_shapes):
         return [(in_shapes[0][0],)]
 
     def grad(self, inp, grads):
@@ -1626,7 +1628,7 @@ optdb.register(
     "fast_compile_gpu", "local_crossentropy_to_crossentropy_with_softmax_grad"
 )  # old name
 @local_optimizer([softmax_grad])
-def local_softmax_grad_to_crossentropy_with_softmax_grad(node):
+def local_softmax_grad_to_crossentropy_with_softmax_grad(fgraph, node):
     if node.op == softmax_grad:
         g_coding_dist, coding_dist = node.inputs
         if (
@@ -1643,11 +1645,11 @@ def local_softmax_grad_to_crossentropy_with_softmax_grad(node):
 
 @register_specialize("fast_compile_gpu")
 @local_optimizer([MaxAndArgmax])
-def local_argmax_pushdown(node):
+def local_argmax_pushdown(fgraph, node):
     if (
         isinstance(node.op, MaxAndArgmax)
         and node.inputs[0].owner
-        and len(node.outputs[0].clients) > 0
+        and len(fgraph.clients[node.outputs[0]]) > 0
         and node.inputs[0].owner.op
         in (
             softmax_op,
@@ -1659,21 +1661,20 @@ def local_argmax_pushdown(node):
             softmax_with_bias,
         )
     ):
-        if theano.config.warn.argmax_pushdown_bug:
+        if theano.config.warn__argmax_pushdown_bug:
             logging.getLogger("theano.tensor.nnet.nnet").warn(
-                "WARNING: there "
-                "was a bug in Theano fixed on May 27th, 2010 in this case."
+                "There was a bug in Theano fixed on May 27th, 2010 in this case."
                 " I.E. when we take the max of a softplus, softmax, exp, "
                 "log, tanh, sigmoid, softmax_with_bias op, we were doing "
                 "the max of the parent of the input. To remove this "
-                "warning set the Theano flags 'warn.argmax_pushdown_bug' "
+                "warning set the Theano flags 'warn__argmax_pushdown_bug' "
                 "to False"
             )
 
     if (
         isinstance(node.op, MaxAndArgmax)
         and node.inputs[0].owner
-        and len(node.outputs[0].clients) == 0
+        and len(fgraph.clients[node.outputs[0]]) == 0
     ):
         x_max, x_argmax = node.outputs
         x = node.inputs[0]
@@ -1702,10 +1703,7 @@ def local_argmax_pushdown(node):
             return ret
 
 
-# Utility function used by the two next optimizations
-
-
-def _check_rows_is_arange_len_labels(rows, labels):
+def _check_rows_is_arange_len_labels(fgraph, rows, labels):
     """Check that `rows` is the same node as `tt.arange(labels.shape[0])`.
 
     Also considers the case where `labels.shape[0]` is constant and equal to 1,
@@ -1714,8 +1712,8 @@ def _check_rows_is_arange_len_labels(rows, labels):
 
     """
 
-    if labels.owner and hasattr(labels.owner.fgraph, "shape_feature"):
-        shape_of = labels.owner.fgraph.shape_feature.shape_of
+    if hasattr(fgraph, "shape_feature"):
+        shape_of = fgraph.shape_feature.shape_of
         # TODO: consider cases where shape_of[labels] is constant, and
         # has a value different from 1.
         # This case is harder, as _is_const only accepts a scalar value
@@ -1744,7 +1742,7 @@ def _check_rows_is_arange_len_labels(rows, labels):
                 if shape_var.owner and shape_var.owner.op == tt.shape:
                     return shape_var.owner.inputs[0] is labels
         else:
-            shape_of = stop.owner.fgraph.shape_feature.shape_of
+            shape_of = fgraph.shape_feature.shape_of
             return shape_of[labels][0] is stop
 
 
@@ -1761,7 +1759,7 @@ def _is_const(z, val, approx=False):
 
 @register_specialize("fast_compile_gpu")
 @local_optimizer([AdvancedSubtensor, log])
-def local_advanced_indexing_crossentropy_onehot(node):
+def local_advanced_indexing_crossentropy_onehot(fgraph, node):
     log_op = None
     sm = None
     # First case: log(softmax(x))[rows, labels]
@@ -1783,7 +1781,7 @@ def local_advanced_indexing_crossentropy_onehot(node):
                 pass
 
     if sm is not None and sm.owner and sm.owner.op in (softmax_op, softmax_with_bias):
-        sm_w_bias = local_softmax_with_bias.transform(sm.owner)
+        sm_w_bias = local_softmax_with_bias.transform(fgraph, sm.owner)
         if sm_w_bias:
             assert sm_w_bias[0].owner.op == softmax_with_bias
             x_var, b_var = sm_w_bias[0].owner.inputs
@@ -1792,7 +1790,7 @@ def local_advanced_indexing_crossentropy_onehot(node):
             b_var = tt.zeros_like(x_var[0])
 
         # Check that rows == arange(labels.shape[0])
-        if _check_rows_is_arange_len_labels(rows, labels):
+        if _check_rows_is_arange_len_labels(fgraph, rows, labels):
             if labels.ndim == 1 and x_var.ndim == 2:
                 minus_ret = crossentropy_softmax_argmax_1hot_with_bias(
                     x_var, b_var, labels
@@ -1804,7 +1802,7 @@ def local_advanced_indexing_crossentropy_onehot(node):
 
 @register_specialize("fast_compile_gpu")
 @local_optimizer([softmax_grad])
-def local_advanced_indexing_crossentropy_onehot_grad(node):
+def local_advanced_indexing_crossentropy_onehot_grad(fgraph, node):
     if not (node.op == softmax_grad):
         return
 
@@ -1819,7 +1817,7 @@ def local_advanced_indexing_crossentropy_onehot_grad(node):
         and sm.owner
         and (sm.owner.op in (softmax_op, softmax_with_bias))
     ):
-        sm_w_bias = local_softmax_with_bias.transform(sm.owner)
+        sm_w_bias = local_softmax_with_bias.transform(fgraph, sm.owner)
         if sm_w_bias:
             assert sm_w_bias[0].owner.op == softmax_with_bias
             x_var, b_var = sm_w_bias[0].owner.inputs
@@ -1942,7 +1940,7 @@ def local_advanced_indexing_crossentropy_onehot_grad(node):
             return
 
         # Check that rows is arange(labels.shape[0])
-        if not _check_rows_is_arange_len_labels(rows, labels):
+        if not _check_rows_is_arange_len_labels(fgraph, rows, labels):
             return
         # else, arguments of AdvancedIncSubtensor are OK,
         # it was really case 1.
@@ -1993,7 +1991,7 @@ def local_advanced_indexing_crossentropy_onehot_grad(node):
             out_grad = -incr
 
             # Check that rows is arange(labels.shape[0])
-            if not _check_rows_is_arange_len_labels(rows, labels):
+            if not _check_rows_is_arange_len_labels(fgraph, rows, labels):
                 return
             # else, arguments of AdvancedIncSubtensor are OK
         else:
@@ -2018,13 +2016,13 @@ def local_advanced_indexing_crossentropy_onehot_grad(node):
 
 @register_specialize("fast_compile_gpu")
 @local_optimizer([softmax_with_bias])
-def graph_merge_softmax_with_crossentropy_softmax(node):
+def graph_merge_softmax_with_crossentropy_softmax(fgraph, node):
     if node.op == softmax_with_bias:
         x, b = node.inputs
-        for x_client in x.clients:
+        for x_client in fgraph.clients[x]:
             if x_client[0].op == crossentropy_softmax_argmax_1hot_with_bias:
                 big_client = x_client[0]
-                if big_client in [b_client[0] for b_client in b.clients]:
+                if big_client in [b_client[0] for b_client in fgraph.clients[b]]:
                     xx, bb, ll = big_client.inputs
                     mergeable_client = big_client.op(x, b, ll)
                     copy_stack_trace(node.outputs[0], mergeable_client[1])
@@ -2035,7 +2033,7 @@ def graph_merge_softmax_with_crossentropy_softmax(node):
 @register_stabilize
 @register_canonicalize
 @local_optimizer([CrossentropySoftmax1HotWithBiasDx])
-def local_useless_crossentropy_softmax_1hot_with_bias_dx_alloc(node):
+def local_useless_crossentropy_softmax_1hot_with_bias_dx_alloc(fgraph, node):
     """
     Replace a CrossentropySoftmax1HotWithBiasDx op, whose incoming gradient is
     an `alloc` of a scalar variable or one that has either broadcastable or
@@ -2060,7 +2058,7 @@ def local_useless_crossentropy_softmax_1hot_with_bias_dx_alloc(node):
             dz = dy.owner.inputs[0]
 
             try:
-                shape_feature = node.fgraph.shape_feature
+                shape_feature = fgraph.shape_feature
             except AttributeError:
                 # The shape feature may not be available in some mode, but we
                 # need it for this optimization, so don't continue.
@@ -2206,7 +2204,7 @@ class Prepend_scalar_constant_to_each_row(Op):
         self.val = val
 
     def __str__(self):
-        return "{}{{{}}}".format(self.__class__.__name__, self.val)
+        return f"{self.__class__.__name__}{{{self.val}}}"
 
     def make_node(self, mat):
         # check type of input
@@ -2239,7 +2237,7 @@ class Prepend_scalar_constant_to_each_row(Op):
         out[:, 0].fill(self.val.data)
         out[:, 1:] = mat
 
-    def infer_shape(self, node, in_shapes):
+    def infer_shape(self, fgraph, node, in_shapes):
         shp = (in_shapes[0][0], in_shapes[0][1] + 1)
         return [shp]
 
@@ -2285,7 +2283,7 @@ class Prepend_scalar_to_each_row(Op):
         out[:, 0].fill(val)
         out[:, 1:] = mat
 
-    def infer_shape(self, node, in_shapes):
+    def infer_shape(self, fgraph, node, in_shapes):
         shp = (in_shapes[1][0], in_shapes[1][1] + 1)
         return [shp]
 
@@ -2612,7 +2610,7 @@ class ScalarSoftsign(UnaryScalarOp):
         (x,) = inp
         (z,) = out
         if node.inputs[0].type in [theano.scalar.float32, theano.scalar.float64]:
-            return "%(z)s = %(x)s / (1.0+fabs(%(x)s));" % locals()
+            return f"{z} = {x} / (1.0+fabs({x}));"
         raise NotImplementedError("only floating point x is implemented")
 
 
