@@ -84,9 +84,9 @@ class ScalarSigmoid(scalar.UnaryScalarOp):
             node.inputs[0].type == scalar.float32
             or node.inputs[0].type == scalar.float16
         ):
-            return """%(z)s = 1.0f / (1.0f + exp(-%(x)s));""" % locals()
+            return f"""{z} = 1.0f / (1.0f + exp(-{x}));"""
         elif node.inputs[0].type == scalar.float64:
-            return """%(z)s = 1.0 / (1.0 + exp(-%(x)s));""" % locals()
+            return f"""{z} = 1.0 / (1.0 + exp(-{x}));"""
         else:
             raise NotImplementedError("only floatingpoint is implemented")
 
@@ -102,7 +102,7 @@ class ScalarSigmoid(scalar.UnaryScalarOp):
         (x,) = inp
         (z,) = out
         if (
-            not theano.config.lib.amdlibm
+            not theano.config.lib__amblibm
             or node.inputs[0].dtype != node.outputs[0].dtype
         ):
             raise theano.gof.utils.MethodNotDefined()
@@ -274,7 +274,7 @@ pprint.assign(ultra_fast_sigmoid, printing.FunctionPrinter("ultra_fast_sigmoid")
 
 # @opt.register_uncanonicalize
 @gof.local_optimizer([sigmoid])
-def local_ultra_fast_sigmoid(node):
+def local_ultra_fast_sigmoid(fgraph, node):
     """
     When enabled, change all sigmoid to ultra_fast_sigmoid.
 
@@ -329,7 +329,7 @@ def hard_sigmoid(x):
 
 # @opt.register_uncanonicalize
 @gof.local_optimizer([sigmoid])
-def local_hard_sigmoid(node):
+def local_hard_sigmoid(fgraph, node):
     if isinstance(node.op, tensor.Elemwise) and node.op.scalar_op == scalar_sigmoid:
         out = hard_sigmoid(node.inputs[0])
         copy_stack_trace(node.outputs[0], out)
@@ -506,14 +506,14 @@ def is_1pexp(t, only_process_constants=True):
                 # Before 7987b51 there used to be a bug where *any* constant
                 # was considered as if it was equal to 1, and thus this
                 # function would incorrectly identify it as (1 + exp(x)).
-                if config.warn.identify_1pexp_bug:
+                if config.warn__identify_1pexp_bug:
                     warnings.warn(
                         "Although your current code is fine, please note that "
                         "Theano versions prior to 0.5 (more specifically, "
                         "prior to commit 7987b51 on 2011-12-18) may have "
                         "yielded an incorrect result. To remove this warning, "
-                        "either set the `warn.identify_1pexp_bug` config "
-                        "option to False, or `warn.ignore_bug_before` to at "
+                        "either set the `warn__identify_1pexp_bug` config "
+                        "option to False, or `warn__ignore_bug_before` to at "
                         "least '0.4.1'."
                     )
     return None
@@ -631,7 +631,7 @@ def is_neg(var):
 
 @opt.register_stabilize
 @gof.local_optimizer([tensor.true_div])
-def local_exp_over_1_plus_exp(node):
+def local_exp_over_1_plus_exp(fgraph, node):
     """
     exp(x)/(1+exp(x)) -> sigm(x)
     c/(1+exp(x)) -> c*sigm(-x)
@@ -908,12 +908,12 @@ def perform_sigm_times_exp(
         full_tree = tree
     if False:  # Debug code.
         print("<perform_sigm_times_exp>")
-        print("  full_tree   = %s" % full_tree)
-        print("  tree        = %s" % tree)
-        print("  exp_x       = %s" % exp_x)
-        print("  exp_minus_x = %s" % exp_minus_x)
-        print("  sigm_x      = %s" % sigm_x)
-        print("  sigm_minus_x= %s" % sigm_minus_x)
+        print(f"  full_tree   = {full_tree}")
+        print(f"  tree        = {tree}")
+        print(f"  exp_x       = {exp_x}")
+        print(f"  exp_minus_x = {exp_minus_x}")
+        print(f"  sigm_x      = {sigm_x}")
+        print(f"  sigm_minus_x= {sigm_minus_x}")
     neg, inputs = tree
     if isinstance(inputs, list):
         # Recurse through inputs of the multiplication.
@@ -982,7 +982,7 @@ def perform_sigm_times_exp(
 
 @opt.register_stabilize
 @gof.local_optimizer([tensor.mul])
-def local_sigm_times_exp(node):
+def local_sigm_times_exp(fgraph, node):
     """
     exp(x) * sigm(-x) -> sigm(x)
     exp(-x) * sigm(x) -> sigm(-x)
@@ -1011,7 +1011,7 @@ def local_sigm_times_exp(node):
 
 @opt.register_stabilize
 @gof.local_optimizer([tensor.inv])
-def local_inv_1_plus_exp(node):
+def local_inv_1_plus_exp(fgraph, node):
     """
     1/(1+exp(x)) -> sigm(-x)
 
@@ -1044,14 +1044,14 @@ def local_inv_1_plus_exp(node):
 
 
 @gof.local_optimizer([tensor.sub])
-def local_1msigmoid(node):
+def local_1msigmoid(fgraph, node):
     """
     1-sigm(x) -> sigm(-x)
 
     """
     if node.op == tensor.sub:
         sub_l, sub_r = node.inputs
-        if len(sub_r.clients) > 1:
+        if len(fgraph.clients[sub_r]) > 1:
             return  # graph is using both sigm and 1-sigm
         if sub_r.owner and sub_r.owner.op == sigmoid:
             try:
