@@ -93,9 +93,10 @@ def pool_2d(
             )
         else:
             warnings.warn(
-                "DEPRECATION: the 'ds' parameter is not going to exist"
+                "The 'ds' parameter is not going to exist"
                 " anymore as it is going to be replaced by the parameter"
                 " 'ws'.",
+                category=DeprecationWarning,
                 stacklevel=2,
             )
             ws = ds
@@ -110,9 +111,10 @@ def pool_2d(
             )
         else:
             warnings.warn(
-                "DEPRECATION: the 'st' parameter is not going to exist"
+                "The 'st' parameter is not going to exist"
                 " anymore as it is going to be replaced by the parameter"
                 " 'stride'.",
+                category=DeprecationWarning,
                 stacklevel=2,
             )
             stride = st
@@ -125,9 +127,10 @@ def pool_2d(
             )
         else:
             warnings.warn(
-                "DEPRECATION: the 'padding' parameter is not going to exist"
+                "The 'padding' parameter is not going to exist"
                 " anymore as it is going to be replaced by the parameter"
                 " 'pad'.",
+                category=DeprecationWarning,
                 stacklevel=2,
             )
             pad = padding
@@ -145,6 +148,7 @@ def pool_2d(
             " GPU combination supported is when"
             " `ws == stride and pad == (0, 0) and mode == 'max'`."
             " Otherwise, the convolution will be executed on CPU.",
+            category=DeprecationWarning,
             stacklevel=2,
         )
         ignore_border = False
@@ -210,9 +214,10 @@ def pool_3d(
             )
         else:
             warnings.warn(
-                "DEPRECATION: the 'ds' parameter is not going to exist"
+                "The 'ds' parameter is not going to exist"
                 " anymore as it is going to be replaced by the parameter"
                 " 'ws'.",
+                category=DeprecationWarning,
                 stacklevel=2,
             )
             ws = ds
@@ -227,9 +232,10 @@ def pool_3d(
             )
         else:
             warnings.warn(
-                "DEPRECATION: the 'st' parameter is not going to exist"
+                "The 'st' parameter is not going to exist"
                 " anymore as it is going to be replaced by the parameter"
                 " 'stride'.",
+                category=DeprecationWarning,
                 stacklevel=2,
             )
             stride = st
@@ -242,9 +248,10 @@ def pool_3d(
             )
         else:
             warnings.warn(
-                "DEPRECATION: the 'padding' parameter is not going to exist"
+                "The 'padding' parameter is not going to exist"
                 " anymore as it is going to be replaced by the parameter"
                 " 'pad'.",
+                category=DeprecationWarning,
                 stacklevel=2,
             )
             pad = padding
@@ -262,6 +269,7 @@ def pool_3d(
             " GPU combination supported is when"
             " `ws == stride and pad == (0, 0, 0) and mode == 'max'`."
             " Otherwise, the convolution will be executed on CPU.",
+            category=DeprecationWarning,
             stacklevel=2,
         )
         ignore_border = False
@@ -387,9 +395,10 @@ class Pool(OpenMPOp):
                 )
             else:
                 warnings.warn(
-                    "DEPRECATION: the 'ds' parameter is not going to exist"
+                    "The 'ds' parameter is not going to exist"
                     " anymore as it is going to be replaced by the parameter"
                     " 'ws'.",
+                    category=DeprecationWarning,
                     stacklevel=2,
                 )
                 ws = ds
@@ -404,9 +413,10 @@ class Pool(OpenMPOp):
                 )
             else:
                 warnings.warn(
-                    "DEPRECATION: the 'st' parameter is not going to exist"
+                    "The 'st' parameter is not going to exist"
                     " anymore as it is going to be replaced by the parameter"
                     " 'stride'.",
+                    category=DeprecationWarning,
                     stacklevel=2,
                 )
                 stride = st
@@ -420,9 +430,10 @@ class Pool(OpenMPOp):
                 )
             else:
                 warnings.warn(
-                    "DEPRECATION: the 'padding' parameter is not going to"
+                    "The 'padding' parameter is not going to"
                     " exist anymore as it is going to be replaced by the"
                     " parameter 'pad'.",
+                    category=DeprecationWarning,
                     stacklevel=2,
                 )
                 pad = padding
@@ -431,7 +442,7 @@ class Pool(OpenMPOp):
             ndim = 2
         assert ndim > 0
         if len(imgshape) < ndim:
-            raise TypeError("imgshape must have at least {} dimensions".format(ndim))
+            raise TypeError(f"imgshape must have at least {ndim} dimensions")
 
         if stride is None:
             stride = ws
@@ -479,7 +490,7 @@ class Pool(OpenMPOp):
         if mode not in ["max", "average_inc_pad", "average_exc_pad", "sum"]:
             raise ValueError(
                 "Pool mode parameter only support 'max', 'sum',"
-                " 'average_inc_pad' and 'average_exc_pad'. Got %s" % mode
+                f" 'average_inc_pad' and 'average_exc_pad'. Got {mode}"
             )
         self.mode = mode
 
@@ -553,7 +564,7 @@ class Pool(OpenMPOp):
         assert ws.shape == stride.shape == pad.shape == (nd,)
         if len(x.shape) < nd:
             raise NotImplementedError(
-                "Pool requires input with {} or more dimensions".format(nd)
+                f"Pool requires input with {nd} or more dimensions"
             )
         z_shape = self.out_shape(x.shape, ws, params.ignore_border, stride, pad, nd)
         if not params.ignore_border:
@@ -600,7 +611,7 @@ class Pool(OpenMPOp):
             for r in np.ndindex(*pool_out_shp):
                 zzk[r] = func(yk[[region_slices[i][r[i]] for i in range(nd)]])
 
-    def infer_shape(self, node, in_shapes):
+    def infer_shape(self, fgraph, node, in_shapes):
         ws, stride, pad = [node.inputs[1], node.inputs[2], node.inputs[3]]
         shp = self.out_shape(
             in_shapes[0], ws, self.ignore_border, stride, pad, self.ndim
@@ -937,7 +948,7 @@ class Pool(OpenMPOp):
                 """
             elif self.mode == "average_inc_pad" and self.ignore_border:
                 # region size = product over all pooling dimensions
-                region_size = " * ".join("ws[%d]" % i for i in range(nd))
+                region_size = " * ".join(f"ws[{i}]" for i in range(nd))
                 ccode += """
                   z[0] = collector / (%(region_size)s);
                 """ % dict(
@@ -945,9 +956,7 @@ class Pool(OpenMPOp):
                 )
             else:
                 # region size = number elements of in this region
-                region_size = " * ".join(
-                    "(r_end[%d]-r_st[%d])" % (i, i) for i in range(nd)
-                )
+                region_size = " * ".join(f"(r_end[{i}]-r_st[{i}])" for i in range(nd))
                 ccode += """
                   z[0] = collector / (%(region_size)s);
                 """ % dict(
@@ -1034,9 +1043,10 @@ class PoolGrad(OpenMPOp):
                 )
             else:
                 warnings.warn(
-                    "DEPRECATION: the 'ds' parameter in PoolGrad is not going"
+                    "The 'ds' parameter in PoolGrad is not going"
                     " to exist anymore as it is going to be replaced by the"
                     " parameter 'ws'.",
+                    category=DeprecationWarning,
                     stacklevel=2,
                 )
                 ws = ds
@@ -1051,9 +1061,10 @@ class PoolGrad(OpenMPOp):
                 )
             else:
                 warnings.warn(
-                    "DEPRECATION: the 'st' parameter in PoolGrad is not going"
+                    "The 'st' parameter in PoolGrad is not going"
                     " to exist anymore as it is going to be replaced by the"
                     " parameter 'stride'.",
+                    category=DeprecationWarning,
                     stacklevel=2,
                 )
                 stride = st
@@ -1066,15 +1077,16 @@ class PoolGrad(OpenMPOp):
                 )
             else:
                 warnings.warn(
-                    "DEPRECATION: the 'padding' parameter in PoolGrad is not"
+                    "The 'padding' parameter in PoolGrad is not"
                     " going to exist anymore as it is going to be replaced"
                     " by the parameter 'pad'.",
+                    category=DeprecationWarning,
                     stacklevel=2,
                 )
                 pad = padding
 
         if len(imgshape) < ndim:
-            raise TypeError("imgshape must have at least {} dimensions".format(ndim))
+            raise TypeError(f"imgshape must have at least {ndim} dimensions")
 
         if stride is None:
             stride = ws
@@ -1118,7 +1130,7 @@ class PoolGrad(OpenMPOp):
         if mode not in ["max", "sum", "average_inc_pad", "average_exc_pad"]:
             raise ValueError(
                 "Pool mode parameter only support 'max', 'sum',"
-                " 'average_inc_pad' and 'average_exc_pad'. Got %s" % mode
+                " 'average_inc_pad' and 'average_exc_pad'. Got {mode}"
             )
         self.mode = mode
         super().__init__(openmp=openmp)
@@ -1153,7 +1165,7 @@ class PoolGrad(OpenMPOp):
                 storage_map[pad] = [None]
                 compute_map[pad] = [False]
 
-    def infer_shape(self, node, in_shapes):
+    def infer_shape(self, fgraph, node, in_shapes):
         return [in_shapes[0]]
 
 
@@ -1200,7 +1212,7 @@ class MaxPoolGrad(PoolGrad):
         assert ws.shape == stride.shape == pad.shape == (nd,)
         if len(x.shape) < nd:
             raise NotImplementedError(
-                "MaxPoolGrad requires input with {} or more dimensions".format(nd)
+                f"MaxPoolGrad requires input with {nd} or more dimensions"
             )
         pool_out_shp = maxout.shape[-nd:]
         img_shp = tuple(x.shape[-nd + i] + 2 * pad[i] for i in range(nd))
@@ -1530,7 +1542,7 @@ class AveragePoolGrad(PoolGrad):
         assert ws.shape == stride.shape == pad.shape == (nd,)
         if len(x.shape) < nd:
             raise NotImplementedError(
-                "AveragePoolGrad requires input with {} or more dimensions".format(nd)
+                f"AveragePoolGrad requires input with {nd} or more dimensions"
             )
         if self.mode == "average_exc_pad" and max(pad) != 0:
             raise NotImplementedError()
@@ -1788,7 +1800,7 @@ class AveragePoolGrad(PoolGrad):
                     val = gz[0] / (%(region_size)s);
                   }
         """
-        region_size = " * ".join("r_pad_width[%d]" % i for i in range(nd))
+        region_size = " * ".join(f"r_pad_width[{i}]" for i in range(nd))
         for i in range(nd):
             ccode += """
                   // go through the pooled region in the unpadded input
@@ -1929,7 +1941,7 @@ class DownsampleFactorMaxGradGrad(OpenMPOp):
                     if maxout_value == yk[c]:
                         ggzk[r] += ggxk[c]
 
-    def infer_shape(self, node, in_shapes):
+    def infer_shape(self, fgraph, node, in_shapes):
         return [in_shapes[1]]
 
     def grad(self, inp, grads):
@@ -2219,7 +2231,7 @@ class MaxPoolRop(OpenMPOp):
         assert ws.shape == stride.shape == pad.shape == (nd,)
         if len(x.shape) < nd:
             raise NotImplementedError(
-                "Pool requires input with {} or more dimensions".format(nd)
+                f"Pool requires input with {nd} or more dimensions"
             )
         z_shape = Pool.out_shape(x.shape, ws, params.ignore_border, stride, pad, nd)
         if not self.ignore_border:
