@@ -55,9 +55,10 @@ class TensorType(Type):
         self.sparse_grad = sparse_grad
         if sparse_grad:
             warnings.warn(
-                "DEPRECATION WARNING: You use an old interface to"
+                "You use an old interface to"
                 " AdvancedSubtensor1 sparse_grad. Now use"
-                " theano.sparse_grad(a_tensor[an_int_vector])."
+                " theano.sparse_grad(a_tensor[an_int_vector]).",
+                category=DeprecationWarning,
             )
 
     def clone(self, dtype=None, broadcastable=None):
@@ -92,29 +93,25 @@ class TensorType(Type):
                 "shared) variable instead of a numeric array?"
             )
 
-        if (type(data) is np.ndarray) and (data.dtype == self.numpy_dtype):
-            if data.dtype.num != self.numpy_dtype.num:
-                data = theano._asarray(data, dtype=self.dtype)
-            # -- now fall through to ndim check
-        elif (type(data) is np.memmap) and (data.dtype == self.numpy_dtype):
+        if isinstance(data, np.memmap) and (data.dtype == self.numpy_dtype):
             # numpy.memmap is a "safe" subclass of ndarray,
             # so we can use it wherever we expect a base ndarray.
             # however, casting it would defeat the purpose of not
             # loading the whole data into memory
             pass
+        elif isinstance(data, np.ndarray) and (data.dtype == self.numpy_dtype):
+            if data.dtype.num != self.numpy_dtype.num:
+                data = theano._asarray(data, dtype=self.dtype)
+            # -- now fall through to ndim check
         elif strict:
             # If any of the two conditions above was not met,
             # we raise a meaningful TypeError.
-            if not (type(data) is np.ndarray):
-                raise TypeError(
-                    "%s expected a ndarray object." % self, data, type(data)
-                )
+            if not isinstance(data, np.ndarray):
+                raise TypeError(f"{self} expected a ndarray object (got {type(data)}).")
             if data.dtype != self.numpy_dtype:
                 raise TypeError(
-                    ("%s expected a ndarray object with " "dtype = %s (got %s).")
-                    % (self, self.numpy_dtype, data.dtype)
+                    f"{self} expected an ndarray with dtype={self.numpy_dtype} (got {data.dtype})."
                 )
-            raise AssertionError("This point should never be reached.")
         else:
             if allow_downcast:
                 # Convert to self.dtype, regardless of the type of data
@@ -134,18 +131,17 @@ class TensorType(Type):
                         data = theano._asarray(data, dtype=self.dtype)
                     if up_dtype != self.dtype:
                         err_msg = (
-                            "%s cannot store a value of dtype %s without "
+                            f"{self} cannot store a value of dtype {data.dtype} without "
                             "risking loss of precision. If you do not mind "
                             "this loss, you can: "
-                            "1) explicitly cast your data to %s, or "
+                            f"1) explicitly cast your data to {self.dtype}, or "
                             '2) set "allow_input_downcast=True" when calling '
-                            '"function". Value: "%s"'
-                            % (self, data.dtype, self.dtype, repr(data))
+                            f'"function". Value: "{repr(data)}"'
                         )
                         raise TypeError(err_msg)
                 elif (
                     allow_downcast is None
-                    and type(data) is float
+                    and isinstance(data, (float, np.floating))
                     and self.dtype == theano.config.floatX
                 ):
                     # Special case where we allow downcasting of Python float
@@ -169,20 +165,20 @@ class TensorType(Type):
                             str_data = str_data[:75] + "(...)"
 
                         err_msg = (
-                            "%s cannot store accurately value %s, "
-                            "it would be represented as %s. "
+                            f"{self} cannot store accurately value {data}, "
+                            f"it would be represented as {converted_data}. "
                             "If you do not mind this precision loss, you can: "
                             "1) explicitly convert your data to a numpy array "
-                            "of dtype %s, or "
+                            f"of dtype {self.dtype}, or "
                             '2) set "allow_input_downcast=True" when calling '
-                            '"function".' % (self, data, converted_data, self.dtype)
+                            '"function".'
                         )
-                        raise TypeError(err_msg, data)
+                        raise TypeError(err_msg)
 
         if self.ndim != data.ndim:
             raise TypeError(
-                "Wrong number of dimensions: expected %s,"
-                " got %s with shape %s." % (self.ndim, data.ndim, data.shape)
+                f"Wrong number of dimensions: expected {self.ndim},"
+                f" got {data.ndim} with shape {data.shape}."
             )
         if not data.flags.aligned:
             try:
@@ -241,10 +237,9 @@ class TensorType(Type):
                 return other2
 
         raise TypeError(
-            "Cannot convert Type %(othertype)s "
-            "(of Variable %(other)s) into Type %(self)s. "
-            "You can try to manually convert %(other)s into a %(self)s."
-            % dict(othertype=other.type, other=other, self=self)
+            f"Cannot convert Type {other.type} "
+            f"(of Variable {other}) into Type {self}. "
+            f"You can try to manually convert {other} into a {self}."
         )
 
     def value_validity_msg(self, a):
@@ -283,9 +278,7 @@ class TensorType(Type):
             }[self.dtype]
         except KeyError:
             raise TypeError(
-                "Unsupported dtype for {}: {}".format(
-                    self.__class__.__name__, self.dtype
-                )
+                f"Unsupported dtype for {self.__class__.__name__}: {self.dtype}"
             )
 
     def to_scalar_type(self):
@@ -392,8 +385,8 @@ class TensorType(Type):
                 if any(b):
                     bcast = str(b)
                 else:
-                    bcast = "%iD" % len(b)
-            return "TensorType({}, {})".format(self.dtype, bcast)
+                    bcast = f"{len(b)}D"
+            return f"TensorType({self.dtype}, {bcast})"
 
     def __repr__(self):
         return str(self)
@@ -698,9 +691,7 @@ def values_eq_approx(
                 # There are no missing values in a, thus this is not the
                 # reason why numpy.allclose(a, b) returned False.
                 _logger.info(
-                    "numpy allclose failed for abs_err %f and rel_err %f",
-                    np.max(abs(a - b)),
-                    np.max(abs(a - b) / (abs(a) + abs(b))),
+                    f"numpy allclose failed for abs_err {np.max(abs(a - b))} and rel_err {np.max(abs(a - b) / (abs(a) + abs(b)))}"
                 )
                 return False
             # The following line is what numpy.allclose bases its decision
