@@ -937,7 +937,7 @@ class TensorConstantSignature(tuple):
             self._sum = self.no_nan.sum()
             # The following 2 lines are needede as in Python 3.3 with NumPy
             # 1.7.1, numpy.ndarray and numpy.memmap aren't hashable.
-            if type(self._sum) is np.memmap:
+            if isinstance(self._sum, np.memmap):
                 self._sum = np.asarray(self._sum).item()
             if self.has_nan and self.no_nan.mask.all():
                 # In this case the sum is not properly computed by numpy.
@@ -994,9 +994,9 @@ class TensorConstant(_tensor_py_operators, Constant):
 
     def __str__(self):
         if self.tag.unique_value is not None:
-            name = "{} of {}".format(str(self.data.shape), str(self.tag.unique_value))
+            name = f"{self.data.shape} of {self.tag.unique_value}"
         else:
-            name = "%s" % self.data
+            name = f"{self.data}"
         if len(name) > 20:
             name = name[:10] + ".." + name[-10:]
 
